/***************************************************************************
                               calltreedlg.h
                             -------------------
    begin                : Fri Jul 18 2003
    copyright            : (C) 2003 by Elad Lahav
    email                : elad_lahav@users.sf.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CALLTREEDLG_H
#define CALLTREEDLG_H

#include <qwidget.h>
#include <qlistview.h>
#include <calltreelayout.h>

/**
 * Displays a hierarchical tree of calling/called functions.
 * Each item in the tree is composed of the function name, the path of the
 * source file in which it is defined, the line number and the full text of
 * that line.
 * @author Elad Lahav
 */

class CallTreeDlg : public CallTreeLayout
{
   Q_OBJECT
   
public: 
	CallTreeDlg(QWidget* pParent = 0, const char* szName = 0);
	~CallTreeDlg();
	
	void setRoot(const QString&);
	bool load(const QString&, const QString&);
	void store(const QString&);
	
	/** Returns Call Tree filename */
	QString getFileName() { return m_sFileName; }

signals:
	/**
	 * Emitted when the user makes a request to view the contents of a
	 * location in the source code.
	 * This can be the location of a call, the definition of a function,
	 * etc.
	 * @param	sPath	The full path of the file to show
	 * @param	nLine	The line number in this file
	 */
	void lineRequested(const QString& sPath, uint nLine);
	
	/**
	 * Emitted when the user closes the tree view.
	 */
	void closed(const CallTreeDlg*);

protected:
	virtual void closeEvent(QCloseEvent*);

protected slots:
	virtual void slotSaveClicked();
	virtual void slotZoomInClicked();
	virtual void slotZoomOutClicked();
	virtual void slotRotateClicked();
	virtual void slotPrefClicked();
	
private:
	/** A unique file name used for storing the call tree on a file.
		The name is a combination of the root function and an incremented
		index. */
	QString m_sFileName;
	
	/** The full path of the file on which the call tree was saved 
		(empty if this graph was never stored). */
	QString m_sFilePath;
		
	/** An index for the generating unique file names. */
	static int s_nFileNameIndex;
};

#endif
