/***************************************************************************
                             calltreemanager.h
                             -------------------
    begin                : Mon Jan 17 2005
    copyright            : (C) 2003 by Elad Lahav
    email                : elad_lahav@users.sf.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CALLTREEMANAGER_H
#define CALLTREEMANAGER_H

#include <qwidget.h>
#include <qptrlist.h>

class CallTreeDlg;

/**
 * Manages all call tree dialogs within the project.
 * Responsible for saving/loading of the call tree dialogs.
 * @author Albert Yosher
 */
class CallTreeManager : public QObject
{
   Q_OBJECT
   
public: 
	CallTreeManager(QWidget*);
	~CallTreeManager();
	
	void saveOpenDialogs(const QString&, QStringList&);
	void loadOpenDialogs(const QString&, const QStringList&);
	CallTreeDlg* addDialog();
	void closeAll();
	
signals:
	/**
	 * Emitted when any call tree dialogue sends a request to view a location
	 * in the source code.
	 * @param	sPath	The full path of the file to show
	 * @param	nLine	The line number in this file
	 */
	void lineRequested(const QString& sPath, uint nLine);
	 
private:
	/** The list of open call tree dialogues. */
	QPtrList<CallTreeDlg> m_lstDialogs;
	
private slots:
	void slotRemoveDialog(const CallTreeDlg*);
};

#endif
