/***************************************************************************
                             configfrontend.cpp
                             -------------------
    begin                : Thu Nov 10 2005
    copyright            : (C) 2005 by Elad Lahav
    email                : elad_lahav@users.sf.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <kstandarddirs.h>
#include "configfrontend.h"

/**
 * Class constructor.
 * @param	bAutoDelete	True to destroy the object when the process ends,
 *						false otherwise
 */
ConfigFrontend::ConfigFrontend(bool bAutoDelete) : 
	Frontend(1, bAutoDelete)
{
}

/**
 * Class destructor.
 */
ConfigFrontend::~ConfigFrontend()
{
}

/**
 * Executes the script using the "sh" shell.
 * @param	sCscopePath	If given, overrides the automatic check for Cscope's
 *						path
 * @param	sCtagsPath	If given, overrides the automatic check for Ctags'
 *						path
 * @return	true if successful, false otherwise
 */
bool ConfigFrontend::run(const QString& sCscopePath, 
	const QString& sCtagsPath)
{
	QStringList slArgs;
	KStandardDirs sd;
	QString sScript;
	
	// Execute using the user's shell
	setUseShell(true);
	
	// Find the configuration script
	sScript = sd.findResource("data", "kscope/kscope_config");
	if (sScript.isEmpty())
		return false;
		
	// Set command line arguments
	slArgs.append("sh");
	slArgs.append(sScript);
	
	// Initialise environment
	setEnvironment("CSCOPE_PATH", sCscopePath);
	setEnvironment("CTAGS_PATH", sCtagsPath);
	
	// Parser initialisation
	m_delim = Newline;
	m_nNextResult = CscopePath;
	
	if (!Frontend::run(slArgs))
		return false;
		
	emit test(CscopePath);
	return true;
}

/**
 * Handles tokens generated by the script.
 * Each token represents a line in the script's output, and is the result of
 * a different test.
 * @param	sToken	The generated token
 */
Frontend::ParseResult ConfigFrontend::parseStdout(QString& sToken, 
	ParserDelim)
{
	uint nResult;
	
	// Store the type of test for which the given token in the result
	nResult = m_nNextResult;
	
	// Determine the next test
	switch (m_nNextResult) {
	case CscopePath:
		if (sToken == "ERROR")
			m_nNextResult = CtagsPath;
		else
			m_nNextResult = CscopeVersion;
		break;
		
	case CscopeVersion:
		if (sToken == "ERROR")
			m_nNextResult = CtagsPath;
		else
			m_nNextResult = CscopeVerbose;
		break;
		
	case CscopeVerbose:
		m_nNextResult = CtagsPath;
		break;
		
	case CtagsPath:
		if (sToken == "ERROR")
			m_nNextResult = END;
		else
			m_nNextResult = CtagsExub;
		break;
	
	case CtagsExub:
		m_nNextResult = END;
		break;
		
	case END:
		return DiscardToken;
	}
	
	// Publish the result and the type of the next test
	emit result(nResult, sToken);
	emit test(m_nNextResult);
	
	return DiscardToken;
}

#include "configfrontend.moc"
