/***************************************************************************
                             historyview.cpp
                             -------------------
    begin                : Wed Aug 24 2005
    copyright            : (C) 2005 by Elad Lahav
    email                : elad_lahav@users.sf.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "historyview.h"

/**
 * Class constructor.
 * @param	pParent	The parent widget
 * @param	szName	The widget's name
 */
HistoryView::HistoryView(QWidget* pParent, const char* szName) :
	QueryView(pParent, szName)
{
}

/**
 * Class destructor.
 */
HistoryView::~HistoryView()
{
}

/**
 * Moves to the previous item in the history, selecting it for display.
 * Note that this function move to the item which chronologically precedes
 * the current one, which, in list view terms, is the next item.
 */
void HistoryView::selectPrev()
{
	QListViewItem* pItem;

	// Get the current item
	pItem = currentItem();
	
	// Select the next item in the list
	if (pItem != NULL && pItem->nextSibling() != NULL) {
		pItem = pItem->nextSibling();
		select(pItem);
	}
}

/**
 * Moves to the next item in the history, selecting it for display.
 * Note that this function move to the item which chronologically succedes
 * the current one, which, in list view terms, is the previous item.
 */
void HistoryView::selectNext()
{
	HistoryItem* pItem;

	// Get the current item
	pItem = (HistoryItem*)currentItem();
	
	// Select the previous item in the list
	if (pItem != NULL && pItem->m_pPrevSibling != NULL) {
		pItem = pItem->m_pPrevSibling;
		select(pItem);
	}
}

/**
 * Deletes the item on which a popup-menu has been invoked.
 * This slot is connected to the remove() signal of the QueryResultsMenu
 * object.
 * @param	pItem	The item to remove
 */
void HistoryView::slotRemoveItem(QListViewItem* pItem)
{
	HistoryItem* pCurItem, * pNextItem;
	
	pCurItem = (HistoryItem*)pItem;
	if ((pNextItem = (HistoryItem*)pCurItem->nextSibling()) != NULL)
		pNextItem->m_pPrevSibling = pCurItem->m_pPrevSibling;
	
	delete pCurItem;
}

#include "historyview.moc"
