/***************************************************************************
                          querypage.h  -  description
                             -------------------
    begin                : Sat May 24 2003
    copyright            : (C) 2003 by Elad Lahav
    email                : elad_lahav@users.sf.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef QUERYPAGE_H
#define QUERYPAGE_H

#include <qwidget.h>
#include <qlistview.h>
#include <qregexp.h>
#include "querypagebase.h"
#include "cscopefrontend.h"

class QueryViewDriver;

/**
 * A QueryWidget page that runs and displays Cscope queries.
 * The page uses a QueryViewDriver object to run queries, and an embedded
 * QueryView widget for displaying query results.
 * @author Elad Lahav
 */
class QueryPage : public QueryPageBase
{
   Q_OBJECT

public: 
	QueryPage(QWidget* pParent = 0, const char* szName = 0);
	~QueryPage();
	
	void query(uint, const QString&);
	void clear();
	bool isRunning();
	
	virtual QString getCaption(bool bBrief = false) const;
	
	/**
	 * @return	The type of query whose results are displayed in this page
	 */
	uint getQueryType() const { return m_nType; }
	
	/**
	 * @return	The text given as a parameter to the query whose results are
	 * displayed in this page.
	 */
	const QString& getQueryText() const { return m_sText; }

protected:
	virtual void addRecord(const QString&, const QString&, const QString&,
		const QString&);
	virtual QString getFileName(const QString&) const;
	virtual bool readHeader(QTextStream&);
	virtual void writeHeader(QTextStream&);

private:
	/** The type of query whose results are listed on this page. */
	uint m_nType;
	
	/** The text given as a parameter to the query. */
	QString m_sText;
	
	/** A formatted caption for this query, including the type of query and
		its text. */
	QString m_sName;
	
private:
	/** Runs Cscope queries whose results are displayed in this page. */
	QueryViewDriver* m_pDriver;
};

#endif
