/***************************************************************************
                             queryviewdriver.h
                             -------------------
    begin                : Wed Aug 24 2005
    copyright            : (C) 2005 by Elad Lahav
    email                : elad_lahav@users.sf.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef QUERYVIEWDRIVER_H
#define QUERYVIEWDRIVER_H

#include <qobject.h>
#include <qlistview.h>
#include "cscopefrontend.h"

class QueryView;

/**
 * Executes a Cscope query and displays the results in a QueryView widget.
 * This class is used in conjunction with QueryView to create a query
 * display object. The driver uses the view widget to display result records
 * of an executed query. It also uses the view as a parent widget for the
 * query progress bar.
 * @author Elad Lahav
 */
class QueryViewDriver : public QObject
{
	Q_OBJECT

public:
    QueryViewDriver(QueryView*, QObject* pParent = 0, const char* szName = 0);
    ~QueryViewDriver();

	void query(uint, const QString&);
	
	/**
	 * @return	true if a query is currently running, false otherwise
	 */
	bool isRunning() { return m_bRunning; }
	
signals:
	/**
	 * Notifies the owner widget that it needs to be visible since some
	 * information is available to display.
	 * This information may be an advancement of the progress bar,
	 * availability of query results, etc.
	 */
	void show();
	
private:
	/** The view to which this object adds result records. */
	QueryView* m_pView;
	
	/** Displays query progress information. */
	CscopeProgress m_progress;
	
	/** This flag is set to true when a query is executed, and back to false
		when the the CscopeFrontend object emits the finished() signal. */
	bool m_bRunning;
	
private slots:
	void slotDataReady(FrontendToken*);
	void slotFinished(uint);
	void slotProgress(int, int);
};

#endif
